from .. import __lib
import networkx
import scipy
import copy
from typing import Optional
# This file contains python wrappers for our C functions.
# The whole purpose of that is to make it easier for
# auto-completions to know our function definitions.

# __lib is the compiled library containing our c functions.

def max_cardinality_matching(rows, cols, matching):
    return __lib.match_wrapper(rows, cols, matching)

def max_cardinality_matching(G: networkx.Graph, init_list: Optional[list] = []):
    sparse = networkx.to_scipy_sparse_array(G,format="csr")
    rows = sparse.indptr.tolist()
    cols = sparse.indices.tolist()
    result_matching = []
    result = __lib.match_wrapper(rows, cols, init_list, result_matching)
    return copy.deepcopy(result_matching)



def __build():
    from distutils.core import setup
    from distutils.core import Extension
    import os
    import glob

    cwd_bup = os.getcwd()

    try:
        modulePath = os.path.dirname(os.path.realpath(__file__))
        print("Building library '" + os.path.basename(modulePath) + "' ...")
    
        os.chdir(modulePath)
    
        sources = glob.glob('__src/**/*.c', recursive=True)
        #print("   Sources:", sources)
    
        module1 = Extension('__lib',
                              sources=sources)

        setup(name='__lib',
                ext_modules=[module1],
                script_args=["-q", "build_ext", "--inplace"])

    finally:
        os.chdir(cwd_bup)

__build()

from .__src.wrappers import *

"""Python Package Template"""
__version__ = "0.0.1"